@@ -8,9 +8,9 @@ class PersonStatus(IntEnum):
 
 
 class TransactionStatus(IntEnum):
-    request = 0  # in proof: receiver sign for request
-    transfer = 1  # in proof: sender sign for transfer
-    valid = 2  # in proof: validator sign for transfer is valid
+    request = 2  # no proof
+    signed = 3  # in proof: sender sign for transfer
+    valid = 4  # in proof: validator sign for transfer is valid
 
 
 class UserStatus(IntEnum):
